# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'gateway.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rgateway.proto\x12\x07gateway\"\xf6\x01\n\rClientMessage\x12$\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.gateway.AuthRequestH\x00\x12.\n\tsubscribe\x18\x02 \x01(\x0b\x32\x19.gateway.SubscribeRequestH\x00\x12\x32\n\x0bunsubscribe\x18\x03 \x01(\x0b\x32\x1b.gateway.UnsubscribeRequestH\x00\x12*\n\x07produce\x18\x04 \x01(\x0b\x32\x17.gateway.ProduceRequestH\x00\x12$\n\x04ping\x18\x05 \x01(\x0b\x32\x14.gateway.PingRequestH\x00\x42\t\n\x07payload\"\xd4\x02\n\rServerMessage\x12.\n\rauth_response\x18\x01 \x01(\x0b\x32\x15.gateway.AuthResponseH\x00\x12(\n\x07message\x18\x02 \x01(\x0b\x32\x15.gateway.KafkaMessageH\x00\x12*\n\x0bproduce_ack\x18\x03 \x01(\x0b\x32\x13.gateway.ProduceAckH\x00\x12.\n\rsubscribe_ack\x18\x04 \x01(\x0b\x32\x15.gateway.SubscribeAckH\x00\x12\x32\n\x0funsubscribe_ack\x18\x05 \x01(\x0b\x32\x17.gateway.UnsubscribeAckH\x00\x12%\n\x04pong\x18\x06 \x01(\x0b\x32\x15.gateway.PongResponseH\x00\x12\'\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x16.gateway.ErrorResponseH\x00\x42\t\n\x07payload\"3\n\x0b\x41uthRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x13\n\x0b\x61gent_names\x18\x02 \x03(\t\"@\n\x0c\x41uthResponse\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x19\n\x11subscribed_topics\x18\x02 \x03(\t\"&\n\x10SubscribeRequest\x12\x12\n\nagent_name\x18\x01 \x01(\t\"\x1d\n\x0cSubscribeAck\x12\r\n\x05topic\x18\x01 \x01(\t\"(\n\x12UnsubscribeRequest\x12\x12\n\nagent_name\x18\x01 \x01(\t\"$\n\x0eUnsubscribeAck\x12\x12\n\nagent_name\x18\x01 \x01(\t\"\xb9\x01\n\x0eProduceRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x35\n\x07headers\x18\x03 \x03(\x0b\x32$.gateway.ProduceRequest.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x04 \x01(\x0c\x12\x16\n\x0e\x63orrelation_id\x18\x05 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\nProduceAck\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x11\n\tpartition\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x16\n\x0e\x63orrelation_id\x18\x04 \x01(\t\"\xd3\x01\n\x0cKafkaMessage\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x11\n\tpartition\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x33\n\x07headers\x18\x05 \x03(\x0b\x32\".gateway.KafkaMessage.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x06 \x01(\x0c\x12\x11\n\ttimestamp\x18\x07 \x01(\x03\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\" \n\x0bPingRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\"B\n\x0cPongResponse\x12\x18\n\x10\x63lient_timestamp\x18\x01 \x01(\x03\x12\x18\n\x10server_timestamp\x18\x02 \x01(\x03\"F\n\rErrorResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x16\n\x0e\x63orrelation_id\x18\x03 \x01(\t2Q\n\x0c\x41gentGateway\x12\x41\n\x0b\x41gentStream\x12\x16.gateway.ClientMessage\x1a\x16.gateway.ServerMessage(\x01\x30\x01\x42 Z\x1e\x61gent-gateway/internal/grpc/pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\036agent-gateway/internal/grpc/pb'
  _globals['_PRODUCEREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PRODUCEREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_KAFKAMESSAGE_HEADERSENTRY']._loaded_options = None
  _globals['_KAFKAMESSAGE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_CLIENTMESSAGE']._serialized_start=27
  _globals['_CLIENTMESSAGE']._serialized_end=273
  _globals['_SERVERMESSAGE']._serialized_start=276
  _globals['_SERVERMESSAGE']._serialized_end=616
  _globals['_AUTHREQUEST']._serialized_start=618
  _globals['_AUTHREQUEST']._serialized_end=669
  _globals['_AUTHRESPONSE']._serialized_start=671
  _globals['_AUTHRESPONSE']._serialized_end=735
  _globals['_SUBSCRIBEREQUEST']._serialized_start=737
  _globals['_SUBSCRIBEREQUEST']._serialized_end=775
  _globals['_SUBSCRIBEACK']._serialized_start=777
  _globals['_SUBSCRIBEACK']._serialized_end=806
  _globals['_UNSUBSCRIBEREQUEST']._serialized_start=808
  _globals['_UNSUBSCRIBEREQUEST']._serialized_end=848
  _globals['_UNSUBSCRIBEACK']._serialized_start=850
  _globals['_UNSUBSCRIBEACK']._serialized_end=886
  _globals['_PRODUCEREQUEST']._serialized_start=889
  _globals['_PRODUCEREQUEST']._serialized_end=1074
  _globals['_PRODUCEREQUEST_HEADERSENTRY']._serialized_start=1028
  _globals['_PRODUCEREQUEST_HEADERSENTRY']._serialized_end=1074
  _globals['_PRODUCEACK']._serialized_start=1076
  _globals['_PRODUCEACK']._serialized_end=1162
  _globals['_KAFKAMESSAGE']._serialized_start=1165
  _globals['_KAFKAMESSAGE']._serialized_end=1376
  _globals['_KAFKAMESSAGE_HEADERSENTRY']._serialized_start=1028
  _globals['_KAFKAMESSAGE_HEADERSENTRY']._serialized_end=1074
  _globals['_PINGREQUEST']._serialized_start=1378
  _globals['_PINGREQUEST']._serialized_end=1410
  _globals['_PONGRESPONSE']._serialized_start=1412
  _globals['_PONGRESPONSE']._serialized_end=1478
  _globals['_ERRORRESPONSE']._serialized_start=1480
  _globals['_ERRORRESPONSE']._serialized_end=1550
  _globals['_AGENTGATEWAY']._serialized_start=1552
  _globals['_AGENTGATEWAY']._serialized_end=1633
# @@protoc_insertion_point(module_scope)
